<?php

/*** Set Content Width ***/

if ( ! isset( $content_width ) )
	$content_width = 940;

	
/*** Theme set up ***/

add_action( 'after_setup_theme', 'silverbow_theme_setup' );

if ( !function_exists('silverbow_theme_setup') ) {

	function silverbow_theme_setup() {
	
		// Register navigation menu
		register_nav_menus(
			array(
				'main-menu' => 'Primary Menu',
			)
		);
		
		// Localization support
		load_theme_textdomain('silverbow', get_template_directory() . '/lang');
		
		// Feed Links
		add_theme_support( 'automatic-feed-links' );
		
		// Post formats
		add_theme_support( 'post-formats', array( 'gallery', 'video', 'audio' ) );

		// Title-tag
		add_theme_support( 'title-tag' );

		// Post thumbnails
		add_theme_support( 'post-thumbnails' );

		// Remove sidebar on Products page
		remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10);

		add_image_size( 'silverbow-full-thumb', 940, 0, true );
		add_image_size( 'silverbow-slider-thumb', 900, 600, true );
		add_image_size( 'silverbow-thumb', 440, 294, true );
		
	
	}

}

/*** WooCommerce settings ***/

// Change number related products
add_filter( 'woocommerce_output_related_products_args', 'silverbow_jk_related_products_args' );
  function silverbow_jk_related_products_args( $args ) {
	$args['posts_per_page'] = 3; // 4 related products
	$args['columns'] = 3; // arranged in 2 columns
	return $args;
}

// Change number or products per row to 3
add_filter('loop_shop_columns', 'silverbow_loop_columns');
if (!function_exists('loop_columns')) {
	function silverbow_loop_columns() {
		return 3;
	}
}

// Remove woocommerce breadcrumb
add_action( 'init', 'silverbow_jk_remove_wc_breadcrumbs' );
function silverbow_jk_remove_wc_breadcrumbs() {
    remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0 );
}

/*** Register & enqueue styles/scripts ***/

add_action( 'wp_enqueue_scripts','silverbow_load_scripts' );

function silverbow_load_scripts() {

	wp_enqueue_style('silverbow-style', esc_url(get_template_directory_uri() . '/style.css'));
	wp_enqueue_style('silverbow-responsive', esc_url(get_template_directory_uri() . '/css/responsive.css'));
	wp_enqueue_style('jquery-bxslider', esc_url(get_template_directory_uri() . '/css/jquery.bxslider.css'));
	wp_enqueue_style('slicknav', esc_url(get_template_directory_uri() . '/css/slicknav.css'));
	wp_enqueue_style('owl-css', esc_url(get_template_directory_uri() . '/css/owl.carousel.css'));
	wp_enqueue_style('owl-theme-css', esc_url(get_template_directory_uri() . '/css/owl.theme.css'));
	wp_enqueue_style('font-awesome-css', esc_url(get_template_directory_uri() . '/css/font-awesome.min.css'));

	wp_enqueue_script('jquery-bxslider', esc_url(get_template_directory_uri() . '/js/jquery.bxslider.min.js'), array('jquery'), false, true);
	wp_enqueue_script('fitvids', esc_url(get_template_directory_uri() . '/js/fitvids.js'), array('jquery'), false, true);
	wp_enqueue_script('jquery-slicknav', esc_url(get_template_directory_uri() . '/js/jquery.slicknav.min.js'), array('jquery'), false, true);
	wp_enqueue_script('owl', esc_url(get_template_directory_uri() . '/js/owl.carousel.min.js'), array('jquery'), false, true);
	wp_enqueue_script('silverbow-script', esc_url(get_template_directory_uri() . '/js/silverbow.js'), array('jquery'), false, true);
	
	if (is_singular() && get_option('thread_comments'))	wp_enqueue_script('comment-reply');
	
}

/** Load Google fonts ***/
function silverbow_google_fonts_url(){

    $fonts_url  = '';
    $Raleway = _x( 'on', 'Raleway font: on or off', 'silverbow' );
    $CrimsonText      = _x( 'on', 'CrimsonText font: on or off', 'silverbow' );
 
    if ( 'off' !== $Raleway || 'off' !== $CrimsonText ){

        $font_families = array();
 
        if ( 'off' !== $Raleway ) {

            $font_families[] = 'Raleway:400,300,500,600,700';

        }
 
        if ( 'off' !== $CrimsonText ) {

            $font_families[] = 'Crimson Text:400,700';

        }
        
 
        $query_args = array(

            'family' => urlencode( implode( '|', $font_families ) ),
            'subset' => urlencode( 'latin,latin-ext' ),
        );
 
        $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );

    }
 
    return esc_url_raw( $fonts_url );
}

function silverbow_enqueue_googlefonts() {

    wp_enqueue_style( 'themeit-googlefonts', silverbow_google_fonts_url(), array(), null );
}

add_action( 'wp_enqueue_scripts', 'silverbow_enqueue_googlefonts' );

/*** Include files ***/

// Theme Options

require get_template_directory() . '/inc/customizer/silverbow_custom_controller.php';
require get_template_directory() . '/inc/customizer/silverbow_customizer_settings.php';
require get_template_directory() . '/inc/customizer/silverbow_customizer_style.php';

// Post like

require get_template_directory() . '/inc/like/index.php';

// Widgets

require get_template_directory() . '/inc/widgets/about_widget.php';
require get_template_directory() . '/inc/widgets/latest_post_widget.php';
require get_template_directory() . '/inc/widgets/social_widget.php';

/*** Register footer widgets ***/

if ( function_exists('register_sidebar') ) {
	register_sidebar(array(
		'name' => esc_html__('Sidebar', 'silverbow'),
		'id' => 'sidebar',
		'description'   => esc_html__('Widgets in this area will be shown on all posts and pages.','silverbow'),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4>',
	));
	register_sidebar(array(
		'name' => esc_html__('Footer 1', 'silverbow'),
		'id' => 'footer-sidebar1',
		'description'   => esc_html__('Widgets in this area will be shown on footer.','silverbow'),
		'before_widget' => '<div id="%1$s" class="widget first %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4>',
	));
	register_sidebar(array(
		'name' => esc_html__('Footer 2', 'silverbow'),
		'id' => 'footer-sidebar2',
		'description'   => esc_html__('Widgets in this area will be shown on footer.','silverbow'),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4>',
	));
	
	register_sidebar(array(
		'name' => esc_html__('Footer 3', 'silverbow'),
		'id' => 'footer-sidebar3',
		'description'   => esc_html__('Widgets in this area will be shown on footer.','silverbow'),
		'before_widget' => '<div id="%1$s" class="widget last %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4>',
	));
}

/*** PAGINATION ***/

function silverbow_pagination() {

	?>
	
	<div class="pagination">
						
		<div class="older"><?php next_posts_link(esc_html__('Older Posts &rarr;', 'silverbow') ); ?></div>
		<div class="newer"><?php previous_posts_link(esc_html__('&larr; Newer Posts', 'silverbow') ); ?></div>
		
	</div>

	<?php
	
}

/*** COMMENTS LAYOUT ***/

	function silverbow_comments($comment, $args, $depth) {
		$GLOBALS['comment'] = $comment;
		
		?>
		<li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>">
			
			<div class="thecomment">
						
				<div class="author-img">
					<?php echo get_avatar($comment,$args['avatar_size']); ?>
				</div>
				
				<div class="comment-text">
					<span class="reply">
						<?php comment_reply_link(array_merge( $args, array('reply_text' => esc_html__('Reply', 'silverbow'), 'depth' => $depth, 'max_depth' => $args['max_depth'])), $comment->comment_ID); ?>
						<?php edit_comment_link(esc_html__('Edit', 'silverbow')); ?>
					</span>
					<span class="author"><?php echo (get_comment_author_link()); ?></span>
					<span class="date"><?php printf(esc_html__('%1$s at %2$s', 'silverbow'), get_comment_date(),  get_comment_time()) ?></span>
					<?php if ($comment->comment_approved == '0') : ?>
						<em><i class="icon-info-sign"></i> <?php esc_html_e('Comment awaiting approval', 'silverbow'); ?></em>
						<br />
					<?php endif; ?>
					<?php comment_text(); ?>
				</div>
						
			</div>
			
			
		</li>

		<?php 
	}


/*** THE EXCERPT ***/

function silverbow_custom_excerpt_length( $length ) {

	return 99;

}

add_filter( 'excerpt_length', 'silverbow_custom_excerpt_length', 999 );

function silverbow_new_excerpt_more( $more ) {

	return '&hellip;';

}

add_filter( 'excerpt_more', 'silverbow_new_excerpt_more' );

function silverbow_string_limit_words($string, $word_limit){

	$words = explode(' ', $string, ($word_limit + 1));
	
	if(count($words) > $word_limit) {

		array_pop($words);

	}
	
	return implode(' ', $words);
	
}

add_action( 'after_setup_theme', 'woocommerce_support' );
function woocommerce_support() {
    add_theme_support( 'woocommerce' );
}